DelayedFuture class

Config of delayed_future. Set duration to define the default delay duration.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

duration Duration
Default duration of the DelayedFutureExtension.delayResult extension.
getter/setter pair
throwImmediatelyOnError bool
Default config of throwImmediatelyOnError. Indicates whether to throw the exception immediately or to delay throwing.
getter/setter pair